@@ -1,31 +1,33 @@
-package HTTP::Daemon; # git description: v6.03-2-gb274cc6
+package HTTP::Daemon; # git description: v6.04-8-g7c078c8
+
 # ABSTRACT: A simple http server class
 
 use strict;
 use warnings;
 
-our $VERSION = '6.04';
+our $VERSION = '6.05';
 
-use IO::Socket qw(AF_INET INADDR_ANY INADDR_LOOPBACK inet_ntoa);
-our @ISA = qw(IO::Socket::INET);
+use Socket qw(
+    AF_INET AF_INET6 INADDR_ANY IN6ADDR_ANY INADDR_LOOPBACK IN6ADDR_LOOPBACK
+    inet_ntop sockaddr_family
+);
+use IO::Socket::IP;
+our @ISA = qw(IO::Socket::IP);
 
 our $PROTO = "HTTP/1.1";
 
 our $DEBUG;
 
-sub new
-{
-    my($class, %args) = @_;
+sub new {
+    my ($class, %args) = @_;
     $args{Listen} ||= 5;
     $args{Proto}  ||= 'tcp';
     return $class->SUPER::new(%args);
 }
 
-
-sub accept
-{
+sub accept {
     my $self = shift;
-    my $pkg = shift || "HTTP::Daemon::ClientConn";
+    my $pkg  = shift || "HTTP::Daemon::ClientConn";
     my ($sock, $peer) = $self->SUPER::accept($pkg);
     if ($sock) {
         ${*$sock}{'httpd_daemon'} = $self;
@@ -36,21 +38,35 @@ sub accept
     }
 }
 
-
-sub url
-{
+sub url {
     my $self = shift;
-    my $url = $self->_default_scheme . "://";
+    my $url  = $self->_default_scheme . "://";
     my $addr = $self->sockaddr;
-    if (!$addr || $addr eq INADDR_ANY) {
- 	require Sys::Hostname;
- 	$url .= lc Sys::Hostname::hostname();
+    if (!$addr || $addr eq INADDR_ANY || $addr eq IN6ADDR_ANY) {
+        require Sys::Hostname;
+        $url .= lc Sys::Hostname::hostname();
     }
     elsif ($addr eq INADDR_LOOPBACK) {
-	$url .= inet_ntoa($addr);
+        $url .= inet_ntop(AF_INET, $addr);
+    }
+    elsif ($addr eq IN6ADDR_LOOPBACK) {
+        $url .= '[' . inet_ntop(AF_INET6, $addr) . ']';
     }
     else {
-	$url .= gethostbyaddr($addr, AF_INET) || inet_ntoa($addr);
+        my $host = $self->sockhostname;
+        if (!defined $host) {
+            my $family = sockaddr_family($self->sockname);
+            if ($family && $family == AF_INET6) {
+                $host = '[' . inet_ntop(AF_INET6, $addr) . ']';
+            }
+            elsif ($family && $family == AF_INET) {
+                $host = inet_ntop(AF_INET, $addr);
+            }
+            else {
+                die "Unknown family";
+            }
+        }
+        $url .= $host;
     }
     my $port = $self->sockport;
     $url .= ":$port" if $port != $self->_default_port;
@@ -58,31 +74,26 @@ sub url
     $url;
 }
 
-
 sub _default_port {
     80;
 }
 
-
 sub _default_scheme {
     "http";
 }
 
-
-sub product_tokens
-{
+sub product_tokens {
     "libwww-perl-daemon/$HTTP::Daemon::VERSION";
 }
 
-
-
-package  # hide from PAUSE
+package    # hide from PAUSE
     HTTP::Daemon::ClientConn;
+
 use strict;
 use warnings;
 
-use IO::Socket ();
-our @ISA = qw(IO::Socket::INET);
+use IO::Socket::IP ();
+our @ISA = qw(IO::Socket::IP);
 our $DEBUG;
 *DEBUG = \$HTTP::Daemon::DEBUG;
 
@@ -93,64 +104,65 @@ use HTTP::Date qw(time2str);
 use LWP::MediaTypes qw(guess_media_type);
 use Carp ();
 
-my $CRLF = "\015\012";   # "\r\n" is not portable
+# "\r\n" is not portable
+my $CRLF     = "\015\012";
 my $HTTP_1_0 = _http_version("HTTP/1.0");
 my $HTTP_1_1 = _http_version("HTTP/1.1");
 
 
-sub get_request
-{
-    my($self, $only_headers) = @_;
+sub get_request {
+    my ($self, $only_headers) = @_;
     if (${*$self}{'httpd_nomore'}) {
         $self->reason("No more requests from this connection");
-	return;
+        return;
     }
 
     $self->reason("");
     my $buf = ${*$self}{'httpd_rbuf'};
     $buf = "" unless defined $buf;
 
-    my $timeout = $ {*$self}{'io_socket_timeout'};
-    my $fdset = "";
+    my $timeout = ${*$self}{'io_socket_timeout'};
+    my $fdset   = "";
     vec($fdset, $self->fileno, 1) = 1;
-    local($_);
+    local ($_);
 
-  READ_HEADER:
+READ_HEADER:
     while (1) {
-	# loop until we have the whole header in $buf
-	$buf =~ s/^(?:\015?\012)+//;  # ignore leading blank lines
-	if ($buf =~ /\012/) {  # potential, has at least one line
-	    if ($buf =~ /^\w+[^\012]+HTTP\/\d+\.\d+\015?\012/) {
-		if ($buf =~ /\015?\012\015?\012/) {
-		    last READ_HEADER;  # we have it
-		}
-		elsif (length($buf) > 16*1024) {
-		    $self->send_error(413); # REQUEST_ENTITY_TOO_LARGE
-		    $self->reason("Very long header");
-		    return;
-		}
-	    }
-	    else {
-		last READ_HEADER;  # HTTP/0.9 client
-	    }
-	}
-	elsif (length($buf) > 16*1024) {
-	    $self->send_error(414); # REQUEST_URI_TOO_LARGE
-	    $self->reason("Very long first line");
-	    return;
-	}
-	print STDERR "Need more data for complete header\n" if $DEBUG;
-	return unless $self->_need_more($buf, $timeout, $fdset);
+
+        # loop until we have the whole header in $buf
+        $buf =~ s/^(?:\015?\012)+//;    # ignore leading blank lines
+        if ($buf =~ /\012/) {           # potential, has at least one line
+            if ($buf =~ /^\w+[^\012]+HTTP\/\d+\.\d+\015?\012/) {
+                if ($buf =~ /\015?\012\015?\012/) {
+                    last READ_HEADER;    # we have it
+                }
+                elsif (length($buf) > 16 * 1024) {
+                    $self->send_error(413);    # REQUEST_ENTITY_TOO_LARGE
+                    $self->reason("Very long header");
+                    return;
+                }
+            }
+            else {
+                last READ_HEADER;              # HTTP/0.9 client
+            }
+        }
+        elsif (length($buf) > 16 * 1024) {
+            $self->send_error(414);            # REQUEST_URI_TOO_LARGE
+            $self->reason("Very long first line");
+            return;
+        }
+        print STDERR "Need more data for complete header\n" if $DEBUG;
+        return unless $self->_need_more($buf, $timeout, $fdset);
     }
     if ($buf !~ s/^(\S+)[ \t]+(\S+)(?:[ \t]+(HTTP\/\d+\.\d+))?[^\012]*\012//) {
-	${*$self}{'httpd_client_proto'} = _http_version("HTTP/1.0");
-	$self->send_error(400);  # BAD_REQUEST
-	$self->reason("Bad request line: $buf");
-	return;
+        ${*$self}{'httpd_client_proto'} = _http_version("HTTP/1.0");
+        $self->send_error(400);                # BAD_REQUEST
+        $self->reason("Bad request line: $buf");
+        return;
     }
     my $method = $1;
-    my $uri = $2;
-    my $proto = $3 || "HTTP/0.9";
+    my $uri    = $2;
+    my $proto  = $3 || "HTTP/0.9";
     $uri = "http://$uri" if $method eq "CONNECT";
     $uri = $HTTP::URI_CLASS->new($uri, $self->daemon->url);
     my $r = HTTP::Request->new($method, $uri);
@@ -159,37 +171,38 @@ sub get_request
     ${*$self}{'httpd_head'} = ($method eq "HEAD");
 
     if ($proto >= $HTTP_1_0) {
-	# we expect to find some headers
-	my($key, $val);
-      HEADER:
-	while ($buf =~ s/^([^\012]*)\012//) {
-	    $_ = $1;
-	    s/\015$//;
-	    if (/^([^:\s]+)\s*:\s*(.*)/) {
-		$r->push_header($key, $val) if $key;
-		($key, $val) = ($1, $2);
-	    }
-	    elsif (/^\s+(.*)/) {
-		$val .= " $1";
-	    }
-	    else {
-		last HEADER;
-	    }
-	}
-	$r->push_header($key, $val) if $key;
+
+        # we expect to find some headers
+        my ($key, $val);
+    HEADER:
+        while ($buf =~ s/^([^\012]*)\012//) {
+            $_ = $1;
+            s/\015$//;
+            if (/^([^:\s]+)\s*:\s*(.*)/) {
+                $r->push_header($key, $val) if $key;
+                ($key, $val) = ($1, $2);
+            }
+            elsif (/^\s+(.*)/) {
+                $val .= " $1";
+            }
+            else {
+                last HEADER;
+            }
+        }
+        $r->push_header($key, $val) if $key;
     }
 
     my $conn = $r->header('Connection');
     if ($proto >= $HTTP_1_1) {
-	${*$self}{'httpd_nomore'}++ if $conn && lc($conn) =~ /\bclose\b/;
+        ${*$self}{'httpd_nomore'}++ if $conn && lc($conn) =~ /\bclose\b/;
     }
     else {
-	${*$self}{'httpd_nomore'}++ unless $conn &&
-                                           lc($conn) =~ /\bkeep-alive\b/;
+        ${*$self}{'httpd_nomore'}++
+            unless $conn && lc($conn) =~ /\bkeep-alive\b/;
     }
 
     if ($only_headers) {
-	${*$self}{'httpd_rbuf'} = $buf;
+        ${*$self}{'httpd_rbuf'} = $buf;
         return $r;
     }
 
@@ -199,8 +212,8 @@ sub get_request
     my $len = $r->header('Content-Length');
 
     # Act on the Expect header, if it's there
-    for my $e ( $r->header('Expect') ) {
-        if( lc($e) eq '100-continue' ) {
+    for my $e ($r->header('Expect')) {
+        if (lc($e) eq '100-continue') {
             $self->send_status_line(100);
             $self->send_crlf;
         }
@@ -212,111 +225,116 @@ sub get_request
     }
 
     if ($te && lc($te) eq 'chunked') {
-	# Handle chunked transfer encoding
-	my $body = "";
-      CHUNK:
-	while (1) {
-	    print STDERR "Chunked\n" if $DEBUG;
-	    if ($buf =~ s/^([^\012]*)\012//) {
-		my $chunk_head = $1;
-		unless ($chunk_head =~ /^([0-9A-Fa-f]+)/) {
-		    $self->send_error(400);
-		    $self->reason("Bad chunk header $chunk_head");
-		    return;
-		}
-		my $size = hex($1);
-		last CHUNK if $size == 0;
 
-		my $missing = $size - length($buf) + 2; # 2=CRLF at chunk end
-		# must read until we have a complete chunk
-		while ($missing > 0) {
-		    print STDERR "Need $missing more bytes\n" if $DEBUG;
-		    my $n = $self->_need_more($buf, $timeout, $fdset);
-		    return unless $n;
-		    $missing -= $n;
-		}
-		$body .= substr($buf, 0, $size);
-		substr($buf, 0, $size+2) = '';
+        # Handle chunked transfer encoding
+        my $body = "";
+    CHUNK:
+        while (1) {
+            print STDERR "Chunked\n" if $DEBUG;
+            if ($buf =~ s/^([^\012]*)\012//) {
+                my $chunk_head = $1;
+                unless ($chunk_head =~ /^([0-9A-Fa-f]+)/) {
+                    $self->send_error(400);
+                    $self->reason("Bad chunk header $chunk_head");
+                    return;
+                }
+                my $size = hex($1);
+                last CHUNK if $size == 0;
 
-	    }
-	    else {
-		# need more data in order to have a complete chunk header
-		return unless $self->_need_more($buf, $timeout, $fdset);
-	    }
-	}
-	$r->content($body);
+                my $missing = $size - length($buf) + 2;    # 2=CRLF at chunk end
+                     # must read until we have a complete chunk
+                while ($missing > 0) {
+                    print STDERR "Need $missing more bytes\n" if $DEBUG;
+                    my $n = $self->_need_more($buf, $timeout, $fdset);
+                    return unless $n;
+                    $missing -= $n;
+                }
+                $body .= substr($buf, 0, $size);
+                substr($buf, 0, $size + 2) = '';
 
-	# pretend it was a normal entity body
-	$r->remove_header('Transfer-Encoding');
-	$r->header('Content-Length', length($body));
+            }
+            else {
+                # need more data in order to have a complete chunk header
+                return unless $self->_need_more($buf, $timeout, $fdset);
+            }
+        }
+        $r->content($body);
 
-	my($key, $val);
-      FOOTER:
-	while (1) {
-	    if ($buf !~ /\012/) {
-		# need at least one line to look at
-		return unless $self->_need_more($buf, $timeout, $fdset);
-	    }
-	    else {
-		$buf =~ s/^([^\012]*)\012//;
-		$_ = $1;
-		s/\015$//;
-		if (/^([\w\-]+)\s*:\s*(.*)/) {
-		    $r->push_header($key, $val) if $key;
-		    ($key, $val) = ($1, $2);
-		}
-		elsif (/^\s+(.*)/) {
-		    $val .= " $1";
-		}
-		elsif (!length) {
-		    last FOOTER;
-		}
-		else {
-		    $self->reason("Bad footer syntax");
-		    return;
-		}
-	    }
-	}
-	$r->push_header($key, $val) if $key;
+        # pretend it was a normal entity body
+        $r->remove_header('Transfer-Encoding');
+        $r->header('Content-Length', length($body));
+
+        my ($key, $val);
+    FOOTER:
+        while (1) {
+            if ($buf !~ /\012/) {
+
+                # need at least one line to look at
+                return unless $self->_need_more($buf, $timeout, $fdset);
+            }
+            else {
+                $buf =~ s/^([^\012]*)\012//;
+                $_ = $1;
+                s/\015$//;
+                if (/^([\w\-]+)\s*:\s*(.*)/) {
+                    $r->push_header($key, $val) if $key;
+                    ($key, $val) = ($1, $2);
+                }
+                elsif (/^\s+(.*)/) {
+                    $val .= " $1";
+                }
+                elsif (!length) {
+                    last FOOTER;
+                }
+                else {
+                    $self->reason("Bad footer syntax");
+                    return;
+                }
+            }
+        }
+        $r->push_header($key, $val) if $key;
 
     }
     elsif ($te) {
-	$self->send_error(501); 	# Unknown transfer encoding
-	$self->reason("Unknown transfer encoding '$te'");
-	return;
+        $self->send_error(501);    # Unknown transfer encoding
+        $self->reason("Unknown transfer encoding '$te'");
+        return;
 
     }
     elsif ($len) {
-	# Plain body specified by "Content-Length"
-	my $missing = $len - length($buf);
-	while ($missing > 0) {
-	    print "Need $missing more bytes of content\n" if $DEBUG;
-	    my $n = $self->_need_more($buf, $timeout, $fdset);
-	    return unless $n;
-	    $missing -= $n;
-	}
-	if (length($buf) > $len) {
-	    $r->content(substr($buf,0,$len));
-	    substr($buf, 0, $len) = '';
-	}
-	else {
-	    $r->content($buf);
-	    $buf='';
-	}
+
+        # Plain body specified by "Content-Length"
+        my $missing = $len - length($buf);
+        while ($missing > 0) {
+            print "Need $missing more bytes of content\n" if $DEBUG;
+            my $n = $self->_need_more($buf, $timeout, $fdset);
+            return unless $n;
+            $missing -= $n;
+        }
+        if (length($buf) > $len) {
+            $r->content(substr($buf, 0, $len));
+            substr($buf, 0, $len) = '';
+        }
+        else {
+            $r->content($buf);
+            $buf = '';
+        }
     }
     elsif ($ct && $ct =~ m/^multipart\/\w+\s*;.*boundary\s*=\s*("?)(\w+)\1/i) {
-	# Handle multipart content type
-	my $boundary = "$CRLF--$2--";
-	my $index;
-	while (1) {
-	    $index = index($buf, $boundary);
-	    last if $index >= 0;
-	    # end marker not yet found
-	    return unless $self->_need_more($buf, $timeout, $fdset);
-	}
-	$index += length($boundary);
-	$r->content(substr($buf, 0, $index));
-	substr($buf, 0, $index) = '';
+
+        # Handle multipart content type
+        my $boundary = "$CRLF--$2--";
+        my $index;
+        while (1) {
+            $index = index($buf, $boundary);
+            last if $index >= 0;
+
+            # end marker not yet found
+            return unless $self->_need_more($buf, $timeout, $fdset);
+        }
+        $index += length($boundary);
+        $r->content(substr($buf, 0, $index));
+        substr($buf, 0, $index) = '';
 
     }
     ${*$self}{'httpd_rbuf'} = $buf;
@@ -324,19 +342,18 @@ sub get_request
     $r;
 }
 
-
-sub _need_more
-{
+sub _need_more {
     my $self = shift;
+
     #my($buf,$timeout,$fdset) = @_;
     if ($_[1]) {
-	my($timeout, $fdset) = @_[1,2];
-	print STDERR "select(,,,$timeout)\n" if $DEBUG;
-	my $n = select($fdset,undef,undef,$timeout);
-	unless ($n) {
-	    $self->reason(defined($n) ? "Timeout" : "select: $!");
-	    return;
-	}
+        my ($timeout, $fdset) = @_[1, 2];
+        print STDERR "select(,,,$timeout)\n" if $DEBUG;
+        my $n = select($fdset, undef, undef, $timeout);
+        unless ($n) {
+            $self->reason(defined($n) ? "Timeout" : "select: $!");
+            return;
+        }
     }
     print STDERR "sysread()\n" if $DEBUG;
     my $n = sysread($self, $_[0], 2048, length($_[0]));
@@ -344,67 +361,53 @@ sub _need_more
     $n;
 }
 
-
-sub read_buffer
-{
+sub read_buffer {
     my $self = shift;
-    my $old = ${*$self}{'httpd_rbuf'};
+    my $old  = ${*$self}{'httpd_rbuf'};
     if (@_) {
-	${*$self}{'httpd_rbuf'} = shift;
+        ${*$self}{'httpd_rbuf'} = shift;
     }
     $old;
 }
 
-
-sub reason
-{
+sub reason {
     my $self = shift;
-    my $old = ${*$self}{'httpd_reason'};
+    my $old  = ${*$self}{'httpd_reason'};
     if (@_) {
         ${*$self}{'httpd_reason'} = shift;
     }
     $old;
 }
 
-
-sub proto_ge
-{
+sub proto_ge {
     my $self = shift;
     ${*$self}{'httpd_client_proto'} >= _http_version(shift);
 }
 
-
-sub _http_version
-{
-    local($_) = shift;
+sub _http_version {
+    local ($_) = shift;
     return 0 unless m,^(?:HTTP/)?(\d+)\.(\d+)$,i;
     $1 * 1000 + $2;
 }
 
-
-sub antique_client
-{
+sub antique_client {
     my $self = shift;
     ${*$self}{'httpd_client_proto'} < $HTTP_1_0;
 }
 
-
-sub force_last_request
-{
+sub force_last_request {
     my $self = shift;
     ${*$self}{'httpd_nomore'}++;
 }
 
-sub head_request
-{
+sub head_request {
     my $self = shift;
     ${*$self}{'httpd_head'};
 }
 
 
-sub send_status_line
-{
-    my($self, $status, $message, $proto) = @_;
+sub send_status_line {
+    my ($self, $status, $message, $proto) = @_;
     return if $self->antique_client;
     $status  ||= RC_OK;
     $message ||= status_message($status) || "";
@@ -412,16 +415,12 @@ sub send_status_line
     print $self "$proto $status $message$CRLF";
 }
 
-
-sub send_crlf
-{
+sub send_crlf {
     my $self = shift;
     print $self $CRLF;
 }
 
-
-sub send_basic_header
-{
+sub send_basic_header {
     my $self = shift;
     return if $self->antique_client;
     $self->send_status_line(@_);
@@ -430,83 +429,80 @@ sub send_basic_header
     print $self "Server: $product$CRLF" if $product;
 }
 
-
-sub send_header
-{
+sub send_header {
     my $self = shift;
     while (@_) {
-	my($k, $v) = splice(@_, 0, 2);
-	$v = "" unless defined($v);
-	print $self "$k: $v$CRLF";
+        my ($k, $v) = splice(@_, 0, 2);
+        $v = "" unless defined($v);
+        print $self "$k: $v$CRLF";
     }
 }
 
-
-sub send_response
-{
+sub send_response {
     my $self = shift;
-    my $res = shift;
+    my $res  = shift;
     if (!ref $res) {
-	$res ||= RC_OK;
-	$res = HTTP::Response->new($res, @_);
+        $res ||= RC_OK;
+        $res = HTTP::Response->new($res, @_);
     }
     my $content = $res->content;
     my $chunked;
     unless ($self->antique_client) {
-	my $code = $res->code;
-	$self->send_basic_header($code, $res->message, $res->protocol);
-	if ($code =~ /^(1\d\d|[23]04)$/) {
-	    # make sure content is empty
-	    $res->remove_header("Content-Length");
-	    $content = "";
-	}
-	elsif ($res->request && $res->request->method eq "HEAD") {
-	    # probably OK
-	}
-	elsif (ref($content) eq "CODE") {
-	    if ($self->proto_ge("HTTP/1.1")) {
-		$res->push_header("Transfer-Encoding" => "chunked");
-		$chunked++;
-	    }
-	    else {
-		$self->force_last_request;
-	    }
-	}
-	elsif (length($content)) {
-	    $res->header("Content-Length" => length($content));
-	}
-	else {
-	    $self->force_last_request;
-            $res->header('connection','close'); 
-	}
-	print $self $res->headers_as_string($CRLF);
-	print $self $CRLF;  # separates headers and content
+        my $code = $res->code;
+        $self->send_basic_header($code, $res->message, $res->protocol);
+        if ($code =~ /^(1\d\d|[23]04)$/) {
+
+            # make sure content is empty
+            $res->remove_header("Content-Length");
+            $content = "";
+        }
+        elsif ($res->request && $res->request->method eq "HEAD") {
+
+            # probably OK
+        }
+        elsif (ref($content) eq "CODE") {
+            if ($self->proto_ge("HTTP/1.1")) {
+                $res->push_header("Transfer-Encoding" => "chunked");
+                $chunked++;
+            }
+            else {
+                $self->force_last_request;
+            }
+        }
+        elsif (length($content)) {
+            $res->header("Content-Length" => length($content));
+        }
+        else {
+            $self->force_last_request;
+            $res->header('connection', 'close');
+        }
+        print $self $res->headers_as_string($CRLF);
+        print $self $CRLF;    # separates headers and content
     }
     if ($self->head_request) {
-	# no content
+
+        # no content
     }
     elsif (ref($content) eq "CODE") {
-	while (1) {
-	    my $chunk = &$content();
-	    last unless defined($chunk) && length($chunk);
-	    if ($chunked) {
-		printf $self "%x%s%s%s", length($chunk), $CRLF, $chunk, $CRLF;
-	    }
-	    else {
-		print $self $chunk;
-	    }
-	}
-	print $self "0$CRLF$CRLF" if $chunked;  # no trailers either
+        while (1) {
+            my $chunk = &$content();
+            last unless defined($chunk) && length($chunk);
+            if ($chunked) {
+                printf $self "%x%s%s%s", length($chunk), $CRLF, $chunk, $CRLF;
+            }
+            else {
+                print $self $chunk;
+            }
+        }
+        print $self "0$CRLF$CRLF" if $chunked;    # no trailers either
     }
     elsif (length $content) {
-	print $self $content;
+        print $self $content;
     }
 }
 
-
-sub send_redirect
-{
-    my($self, $loc, $status, $content) = @_;
+sub send_redirect {
+    my ($self, $loc, $status, $content) = @_;
     $status ||= RC_MOVED_PERMANENTLY;
     Carp::croak("Status '$status' is not redirect") unless is_redirect($status);
     $self->send_basic_header($status);
@@ -514,23 +510,22 @@ sub send_redirect
     $loc = $HTTP::URI_CLASS->new($loc, $base) unless ref($loc);
     $loc = $loc->abs($base);
     print $self "Location: $loc$CRLF";
+
     if ($content) {
-	my $ct = $content =~ /^\s*</ ? "text/html" : "text/plain";
-	print $self "Content-Type: $ct$CRLF";
+        my $ct = $content =~ /^\s*</ ? "text/html" : "text/plain";
+        print $self "Content-Type: $ct$CRLF";
     }
     print $self $CRLF;
     print $self $content if $content && !$self->head_request;
-    $self->force_last_request;  # no use keeping the connection open
+    $self->force_last_request;    # no use keeping the connection open
 }
 
-
-sub send_error
-{
-    my($self, $status, $error) = @_;
+sub send_error {
+    my ($self, $status, $error) = @_;
     $status ||= RC_BAD_REQUEST;
     Carp::croak("Status '$status' is not an error") unless is_error($status);
     my $mess = status_message($status);
-    $error  ||= "";
+    $error ||= "";
     $mess = <<EOT;
 <title>$status $mess</title>
 <h1>$status $mess</h1>
@@ -539,79 +534,71 @@ EOT
     unless ($self->antique_client) {
         $self->send_basic_header($status);
         print $self "Content-Type: text/html$CRLF";
-	print $self "Content-Length: " . length($mess) . $CRLF;
+        print $self "Content-Length: " . length($mess) . $CRLF;
         print $self $CRLF;
     }
     print $self $mess unless $self->head_request;
     $status;
 }
 
-
-sub send_file_response
-{
-    my($self, $file) = @_;
+sub send_file_response {
+    my ($self, $file) = @_;
     if (-d $file) {
-	$self->send_dir($file);
+        $self->send_dir($file);
     }
     elsif (-f _) {
-	# plain file
-	local(*F);
-	sysopen(F, $file, 0) or 
-	  return $self->send_error(RC_FORBIDDEN);
-	binmode(F);
-	my($ct,$ce) = guess_media_type($file);
-	my($size,$mtime) = (stat _)[7,9];
-	unless ($self->antique_client) {
-	    $self->send_basic_header;
-	    print $self "Content-Type: $ct$CRLF";
-	    print $self "Content-Encoding: $ce$CRLF" if $ce;
-	    print $self "Content-Length: $size$CRLF" if $size;
-	    print $self "Last-Modified: ", time2str($mtime), "$CRLF" if $mtime;
-	    print $self $CRLF;
-	}
-	$self->send_file(\*F) unless $self->head_request;
-	return RC_OK;
+
+        # plain file
+        local (*F);
+        sysopen(F, $file, 0) or return $self->send_error(RC_FORBIDDEN);
+        binmode(F);
+        my ($ct, $ce) = guess_media_type($file);
+        my ($size, $mtime) = (stat _)[7, 9];
+        unless ($self->antique_client) {
+            $self->send_basic_header;
+            print $self "Content-Type: $ct$CRLF";
+            print $self "Content-Encoding: $ce$CRLF" if $ce;
+            print $self "Content-Length: $size$CRLF" if $size;
+            print $self "Last-Modified: ", time2str($mtime), "$CRLF" if $mtime;
+            print $self $CRLF;
+        }
+        $self->send_file(\*F) unless $self->head_request;
+        return RC_OK;
     }
     else {
-	$self->send_error(RC_NOT_FOUND);
+        $self->send_error(RC_NOT_FOUND);
     }
 }
 
-
-sub send_dir
-{
-    my($self, $dir) = @_;
+sub send_dir {
+    my ($self, $dir) = @_;
     $self->send_error(RC_NOT_FOUND) unless -d $dir;
     $self->send_error(RC_NOT_IMPLEMENTED);
 }
 
-
-sub send_file
-{
-    my($self, $file) = @_;
+sub send_file {
+    my ($self, $file) = @_;
     my $opened = 0;
-    local(*FILE);
+    local (*FILE);
     if (!ref($file)) {
-	open(FILE, $file) || return undef;
-	binmode(FILE);
-	$file = \*FILE;
-	$opened++;
+        open(FILE, $file) || return undef;
+        binmode(FILE);
+        $file = \*FILE;
+        $opened++;
     }
     my $cnt = 0;
     my $buf = "";
     my $n;
-    while ($n = sysread($file, $buf, 8*1024)) {
-	last if !$n;
-	$cnt += $n;
-	print $self $buf;
+    while ($n = sysread($file, $buf, 8 * 1024)) {
+        last if !$n;
+        $cnt += $n;
+        print $self $buf;
     }
     close($file) if $opened;
     $cnt;
 }
 
-
-sub daemon
-{
+sub daemon {
     my $self = shift;
     ${*$self}{'httpd_daemon'};
 }
@@ -631,7 +618,7 @@ HTTP::Daemon - A simple http server class
 
 =head1 VERSION
 
-version 6.04
+version 6.05
 
 =head1 SYNOPSIS
 
@@ -658,12 +645,12 @@ version 6.04
 
 Instances of the C<HTTP::Daemon> class are HTTP/1.1 servers that
 listen on a socket for incoming requests. The C<HTTP::Daemon> is a
-subclass of C<IO::Socket::INET>, so you can perform socket operations
+subclass of C<IO::Socket::IP>, so you can perform socket operations
 directly on it too.
 
 The accept() method will return when a connection from a client is
 available.  The returned value will be an C<HTTP::Daemon::ClientConn>
-object which is another C<IO::Socket::INET> subclass.  Calling the
+object which is another C<IO::Socket::IP> subclass.  Calling the
 get_request() method on this object will read data from the client and
 return an C<HTTP::Request> object.  The ClientConn object also provide
 methods to send back various responses.
@@ -674,7 +661,7 @@ desirable.  Also note that the user is responsible for generating
 responses that conform to the HTTP/1.1 protocol.
 
 The following methods of C<HTTP::Daemon> are new (or enhanced) relative
-to the C<IO::Socket::INET> base class:
+to the C<IO::Socket::IP> base class:
 
 =over 4
 
@@ -683,7 +670,7 @@ to the C<IO::Socket::INET> base class:
 =item $d = HTTP::Daemon->new( %opts )
 
 The constructor method takes the same arguments as the
-C<IO::Socket::INET> constructor, but unlike its base class it can also
+C<IO::Socket::IP> constructor, but unlike its base class it can also
 be called without any arguments.  The daemon will then set up a listen
 queue of 5 connections and allocate some random port number.
 
@@ -695,7 +682,7 @@ HTTP port will be constructed like this:
            LocalPort => 80,
        );
 
-See L<IO::Socket::INET> for a description of other arguments that can
+See L<IO::Socket::IP> for a description of other arguments that can
 be used configure the daemon during construction.
 
 =item $c = $d->accept
@@ -712,7 +699,7 @@ class a subclass of C<HTTP::Daemon::ClientConn>.
 
 The accept method will return C<undef> if timeouts have been enabled
 and no connection is made within the given time.  The timeout() method
-is described in L<IO::Socket>.
+is described in L<IO::Socket::IP>.
 
 In list context both the client object and the peer address will be
 returned; see the description of the accept method L<IO::Socket> for
@@ -734,7 +721,7 @@ replaced with the version number of this module.
 
 =back
 
-The C<HTTP::Daemon::ClientConn> is a C<IO::Socket::INET>
+The C<HTTP::Daemon::ClientConn> is a C<IO::Socket::IP>
 subclass. Instances of this class are returned by the accept() method
 of C<HTTP::Daemon>.  The following methods are provided:
 
@@ -908,7 +895,7 @@ Return a reference to the corresponding C<HTTP::Daemon> object.
 
 RFC 2616
 
-L<IO::Socket::INET>, L<IO::Socket>
+L<IO::Socket::IP>, L<IO::Socket>
 
 =head1 SUPPORT
 
@@ -926,7 +913,7 @@ Gisle Aas <gisle@activestate.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Ville Skyttä Olaf Alders Mark Stosberg Slaven Rezic Karen Etheridge Zefram Tom Hukins Chase Whitener Mike Schilli Alexey Tourbin Bron Gondwana Hans-H. Froehlich Ian Kilgore Jacob J Ondrej Hanak Perlover Peter Rabbitson Robert Stone Rolf Grossmann Sean M. Burke Spiros Denaxas Steve Hay Todd Lipcon Tony Finch Toru Yamaguchi Yuri Karaban amire80 jefflee john9art murphy phrstbrn ruff Adam Kennedy sasao Sjogren Alex Kapranoff Andreas J. Koenig Bill Mann DAVIDRW Daniel Hedlund David E. Wheeler FWILES Father Chrysostomos Gavin Peters Graeme Thompson
+=for stopwords Ville Skyttä Olaf Alders Mark Stosberg Karen Etheridge Chase Whitener Slaven Rezic Zefram Tom Hukins Mike Schilli Alexey Tourbin Bron Gondwana Hans-H. Froehlich Ian Kilgore Jacob J Ondrej Hanak Perlover Peter Rabbitson Robert Stone Rolf Grossmann Sean M. Burke Spiros Denaxas Steve Hay Todd Lipcon Tony Finch Toru Yamaguchi Yuri Karaban amire80 jefflee john9art murphy phrstbrn ruff Adam Kennedy sasao Sjogren Alex Kapranoff Andreas J. Koenig Bill Mann DAVIDRW Daniel Hedlund David E. Wheeler FWILES Father Chrysostomos Gavin Peters Graeme Thompson
 
 =over 4
 
@@ -944,11 +931,15 @@ Mark Stosberg <MARKSTOS@cpan.org>
 
 =item *
 
-Slaven Rezic <slaven@rezic.de>
+Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Karen Etheridge <ether@cpan.org>
+Chase Whitener <capoeirab@cpan.org>
+
+=item *
+
+Slaven Rezic <slaven@rezic.de>
 
 =item *
 
@@ -960,10 +951,6 @@ Tom Hukins <tom@eborcom.com>
 
 =item *
 
-Chase Whitener <capoeirab@cpan.org>
-
-=item *
-
 Mike Schilli <mschilli@yahoo-inc.com>
 
 =item *
